;
; Assemble this file at any of the following locations:
;
; Maplin card  - 0800H
; ETI Z80 card - 8000H
; Z88          - 9c40H

;
; This is a list of system variables for use with the remote monitor
; It can be included into any program using the monitor when it 
; is desired to use any of the system variables
;
; (C) Copyright, Robin Abbott, 1989 V1.1
;


RXBUF:          DEFS 80H       ; 128 byte buffer for receive data
TXBUF:          DEFS 80H       ; 128 byte buffer for transmit data 
;
; The next 4 bytes are pointers to the transmit and receive buffers
; the head is address to insert the next byte, the tail is the next
; byte to be taken from the buffer. The buffers are circular and only
; 7 bits of the pointers are significant.
;

RXHEAD:         DEFB 0
RXTAIL:         DEFB 0
TXHEAD:         DEFB 0
TXTAIL:         DEFB 0

;
; The next byte is a flag for the operation of the serial port, some 
; of the bits may be set by the user. The bits have the following
; meanings:
;
;       Bit 0 : XOFF has been received
;       Bit 1 : XOFF has been sent
;       Bit 2 : 0=XON/XOFF flow control, 1=No flow control
;       Bit 3 : 0=Transmit Enabled, 1=Transmit Disabled
;       Bit 4 : Set to send an immediate XON bypassing the buffer
;       Bit 5 : Set to send and immediate XOFF bypassing the buffer
;
; The user may modify bits 2,4 and 5. 
; When setting bit 2 to 1 then also ensure that bit 3 is reset.
; When resetting bit 2 to 0 then set bits 0 and 1 to 0 at the same time.
; The default power up condition is flow control enabled, bit 2 reset to 0
;

UARTFLAGS:      DEFB 0          ; FLAG OPERATION
XOFFRX:         EQU 1           ;
XOFFTX:         EQU 2           ;
FLOWCNT:        EQU 4           ; BIT MEANINGS
TXEN:           EQU 8           ;
SENDXON:        EQU &10         ;
SENDXOFF:       EQU &20         ;
XON:            EQU 17          ; The XON character
XOFF:           EQU 19          ; The XOFF character
ESC:		EQU 27		; The ESCAPE character

;
; The next series of words are a series of vectors normally they point
; to a return routine. To hook a routine into a vector, such as an 
; interrupt handler then read the current value of the vector and save
; it, then put the address of your routine into the vector. Now your
; own routine should perform its actions and then when it completes should
; jump to the earlier saved address. However see descriptions of each
; routine for further details of return procedures.
;

; 
; This is the RST &38, interrupt service routine. The monitor will save
; AF,DE,BC and HL for you but no other registers ! The monitor checks the
; serial port for interrupt service requests first and services any that
; it finds, then it will jump to the vector in INTJP. 
;
; After running the interrupt routine you can either jump to the address found
; in the vector, or if you are the sole user then you can jump to address
; DIRET.

INTJP:          DEFW 0          ; Interrupt RST &38 routine
DIRET:          EQU &0051       ; Return address from Maskable Interrupt

;
; The following interrupt address (RST &8) is used internally to the monitor
; to place a breakpoint. Unless your program plans to abandon breakpoints 
; then it should not use it.
;

RES8JP:         DEFW 0          ; Interrupt RST &8 routine

;
; The following interrupt is used to hook into the monitor routines. Load
; the E register with the required service and then issue an RST &10 
; instruction. The DE register is destroyed.
;
; For example:
;               LD A,'A'                ; To transmit A on the serial port
;               LD E,TXWAIT
;               RST &10
;
; The routines available are as follows:
;
;       E register      Function
;       ---------------------------------------------------------------------
;       RXWAIT (0)      Get the next character from the receive buffer, if
;                       no characters are available then wait until one is
;                       received.
;       RX (1)          Get the next character from the receive buffer and 
;                       return it in the A register. If none is available
;                       then wait for about 1 second and then return with
;                       the Z flag set if none was received.
;       TXWAIT (2)      Put the character in the A register to the serial
;                       port transmit buffer. If there is no space then
;                       wait until the buffer clears.
;       TX (3)          Put the character in the A register to the serial 
;                       port transmit buffer. If no space is available
;                       then wait for about 1 second and then return with
;                       the Z flag set if the character was not added.
;       BREAK (4)       Call this routine to allow the breakit program to
;                       operate. When called the routine waits about 1.5S
;                       and if a &FF character is recived breaks into the
;                       monitor. If not it returns.
;       RXAVAIL (5)     Returns Z flag set if receive buffer empty, or reset
;                       if there are characters in the buffer.
;       TXAVAIL (6)     Returns Z flag set if the transmit buffer is full, or
;                       reset if there is space available.
;
;       The user should not change this value unless there is a very good
;       reason to do so, or if the routines are not required.
;


RES10JP:        DEFW 0
RXWAIT:         EQU 0
RX:             EQU 1
TXWAIT:         EQU 2
TX:             EQU 3
BREAK:          EQU 4
RXAVAIL:        EQU 5
TXAVAIL:        EQU 6

;
; The following routines are free for use by the user. The code at each
; of the interrupt routines follows the same form as for RST &18, which
; looks like:
;
;       PUSH HL
;       LD HL,(RES18JP)
;       JP (HL)
;
; Your routine should POP HL and treat itself as a normally called routine.
;

RES18JP:        DEFW 0
RES20JP:        DEFW 0
RES28JP:        DEFW 0
RES30JP:        DEFW 0

;
; The NMI routine looks like this :
;
;                ORG &66
;                PUSH HL                ; save HL and Flags
;                PUSH AF                
;                LD HL,(RES66JP)        
;                LD A,H                 ; Check if HL is 0, if so abandon NMI
;                OR L                   
;                JR Z,NMRET             
;                JP (HL)                
;NMRET:          POP AF                
;                POP HL                
;                RETN                  

NMIJP:          DEFW 0
MEMTOP:         DEFW 0
MAGIC:          DEFW 0
AJUMP:          DEFW 0
CHK:            DEFB 0
SAVAF:          DEFW 0
SAVBC:          DEFW 0
SAVDE:          DEFW 0
SAVHL:          DEFW 0
SAVAFA:         DEFW 0
SAVBCA:         DEFW 0
SAVDEA:         DEFW 0
SAVHLA:         DEFW 0
SAVX:           DEFW 0
SAVY:           DEFW 0
SAVIR:          DEFW 0
SAVSP:          DEFW 0
SAVPC:          DEFW 0
BP0:            DEFS &78
TEMP:           DEFW 0
ISTACK:         DEFS 150
PSTACK:         DEFS 50       ; istack +150, THIS IS 
ISEND:          DEFB 0
USER:           DEFB 0
